@@ -19,6 +19,9 @@ class CLI(object):
         self.parser.add_argument('-n', '--num-across', type=int,
                 dest='num_across', default=10, help='Number of hexagons for \
                 the grid to have across (approximate)')
+        self.parser.add_argument('-e', '--exclude-empty', \
+                dest='exclude_empty', action='store_true', \
+                help='Exclude shapes that end up binning zero points.')
         self.parser.add_argument('-o', '--overwrite', action='store_true', \
                 help='Overwrite output file.')
         self.parser.add_argument('--ignore-type', action='store_true', \
